@@ -21,10 +21,9 @@ class MatrixGenerator(_BasicDataGenerator):
     def __init__(self):
         super().__init__()
 
-    def generate(self,n_rows = 100, n_cols = 10, seed = None, noise_sigma_man_std = (0,1)):
+    def generate(self,n_rows = 100, n_cols = 10, noise_sigma_man_std = (0,1), seed = None):
         assert isinstance(n_rows, int), "Argument `n_rows` must be int."
         assert isinstance(n_cols, int), "Argument `n_cols` must be int."
-        assert isinstance(seed, int), "Argument `seed` must be int."
         assert isinstance(noise_sigma_man_std, tuple) and len(noise_sigma_man_std) == 2, "Argument `noise_sigma_man_std` must be tuple of length 2."
 
         super().generate(n_rows, n_cols, seed)
@@ -54,10 +53,9 @@ class DataFrameGenerator(_BasicDataGenerator):
         new_cols = ['var_' + str(i) for i in np.arange(1,n+1)]
         return new_cols
 
-    def generate(self,n_rows = 100, n_cols = 10, seed = None, noise_sigma_man_std = (0,1)):
+    def generate(self,n_rows = 100, n_cols = 10, noise_sigma_man_std = (0,1), seed = None):
         assert isinstance(n_rows, int), "Argument `n_rows` must be int."
         assert isinstance(n_cols, int), "Argument `n_cols` must be int."
-        assert isinstance(seed, int), "Argument `seed` must be int."
         assert isinstance(noise_sigma_man_std, tuple) and len(noise_sigma_man_std) == 2, "Argument `noise_sigma_man_std` must be tuple of length 2."
 
         self.noise_sigma_mean = noise_sigma_man_std[0]
